<?php 

// DOCUMENT: Funktionen, die zur Spalten-Bearbeitung dienen.
// AUTHOR: M.Beranek <marcus@beranek.de>
// DATE: 03.09.2006
// COPYRIGHT: M.Beranek

define( "DB_FUNCTIONS_COLUMN", 1 );


define( "COLUMN_CLASS_UNKNOWN", 0 );
define( "COLUMN_CLASS_INTEGER", 1 );
define( "COLUMN_CLASS_BOOLEAN", 2 );
define( "COLUMN_CLASS_DATETIME", 3 );
define( "COLUMN_CLASS_FLOAT", 4 );
define( "COLUMN_CLASS_STRING", 5 );




/**
Formats the columns-name as used in the database into a 
format, which is more usefull for programming-languages.
I.e.: remove underscores and replace them with mixed-case
writing.
@param string s column-name, as used in database
@return string column-name, as used in programming-language
@author M.Beranek
*/
function getMixedCase( $columnName )
{
	// Some databases show columnnames in uppercase,
	// so we move the name to lowercase.
	$columnNameLow = strtolower($columnName);
	
	// Length of column-name:
	$colLength = strlen($columnNameLow);
	
	// What case should the next character have?
	// We are starting in lowercase!
	$isCharLow = true;
	
	// Buffer:
	$colNameBuffer = "";
	
	for( $pos=0; $pos<$colLength; $pos++)
	{
		// Current character:
		$character = $columnNameLow[ $pos ];
		
		// Drop underscores:
		if( $character != "_" )
		{
			
			if( $isCharLow )
			{
				
				// $character is lowercase already, no need to tracsform:
				$colNameBuffer .= $character;
				
			} 
			else 
			{
				
				// Character is written in uppercase
				$colNameBuffer .= strtoupper($character);
				
				// The next character will be lowercase again:
				$isCharLow = true;
				
			}
			
		}
		else
		{
			// If the last character was an underscore,
			// write the next character in uppercase!
			$isCharLow = false;
		}
	}
	
	return $colNameBuffer;
	
	
	
}



/**
TODO: Description
@param integer i Description
@param boolean b Description
@param string s Description
@return integer Description
@author M.Beranek
*/
function classifyColumnType( $colType )
{
	$columnClass = COLUMN_CLASS_UNKNOWN;
	
	if( preg_match( "/int\(.+/", $colType) )
	{
		$columnClass = COLUMN_CLASS_INTEGER;
	}
	
	elseif( preg_match( "/tinyint\(.+/", $colType) )
	{
		$columnClass = COLUMN_CLASS_INTEGER;
	}
	
	elseif( preg_match( "/smallint\(.+/", $colType) )
	{
		$columnClass = COLUMN_CLASS_INTEGER;
	}
	
	elseif( preg_match( "/mediumint\(.+/", $colType) )
	{
		$columnClass = COLUMN_CLASS_INTEGER;
	}
	
	elseif( preg_match( "/longint\(.+/", $colType) )
	{
		$columnClass = COLUMN_CLASS_INTEGER;
	}
	
	elseif( preg_match( "/varchar\(.+/", $colType) )
	{
		$columnClass = COLUMN_CLASS_STRING;
	}
	
	elseif( preg_match( "/char\(.+/", $colType) )
	{
		$columnClass = COLUMN_CLASS_STRING;
	}
	
	elseif( preg_match( "/text/", $colType) )
	{
		$columnClass = COLUMN_CLASS_STRING;
	}
	
	elseif( preg_match( "/date/", $colType) )
	{
		$columnClass = COLUMN_CLASS_DATETIME;
	}
	
	elseif( preg_match( "/timestamp/", $colType) )
	{
		$columnClass = COLUMN_CLASS_DATETIME;
	}
	
	elseif( preg_match( "/float\(.+/", $colType) )
	{
		$columnClass = COLUMN_CLASS_FLOAT;
	}
	
	elseif( preg_match( "/double\(.+/", $colType) )
	{
		$columnClass = COLUMN_CLASS_FLOAT;
	}
	
	// Sonderfall: tinyint(1) wird immer als Bool behandelt...
	if( $colType == "tinyint(1)" )
	{
		$columnClass = COLUMN_CLASS_BOOLEAN;
	}
	
	
	
	return $columnClass;
	
}





?>
